==> entity_visibility_preview-8.x-1.6.tar.gz: entity_visibility_preview/tests/src/Functional/DateRangeConditionTest.php <==
<?php

declare(strict_types = 1);

namespace Drupal\Tests\entity_visibility_preview\Functional;

use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;
use Drupal\node\NodeInterface;

/**
 * Tests for the Date range condition plugin.
 *
 * @group entity_visibility_preview
 */
class DateRangeConditionTest extends EntityVisibilityPreviewFunctionalTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'datetime',
  ];

  /**
   * {@inheritdoc}
   */
  protected $fieldSettings = [
    'enabled_condition_plugins' => [
      'date_range_condition' => 'date_range_condition',
    ],
  ];

  /**
   * Test the cases of the date range plugin.
   */
  public function testDateRangePlugin() {
    /** @var \Drupal\Core\Datetime\DateFormatterInterface $date_formatter */
    $date_formatter = $this->container->get('date.formatter');
    $ten_days_in_the_past = $date_formatter->format(strtotime('-10 days'), 'custom', DateTimeItemInterface::DATE_STORAGE_FORMAT);
    $five_days_in_the_past = $date_formatter->format(strtotime('-5 days'), 'custom', DateTimeItemInterface::DATE_STORAGE_FORMAT);
    $today = $date_formatter->format(strtotime('today'), 'custom', DateTimeItemInterface::DATE_STORAGE_FORMAT);
    $five_days_in_the_future = $date_formatter->format(strtotime('+5 days'), 'custom', DateTimeItemInterface::DATE_STORAGE_FORMAT);
    $ten_days_in_the_future = $date_formatter->format(strtotime('+10 days'), 'custom', DateTimeItemInterface::DATE_STORAGE_FORMAT);

    $node = $this->drupalCreateNode([
      'type' => 'article',
      'status' => NodeInterface::PUBLISHED,
    ]);

    // Test that the user has access to the node.
    $this->dateRangeTest($node, 200, '', '');

    // Begin date.
    $this->dateRangeTest($node, 200, $ten_days_in_the_past, '');
    $this->dateRangeTest($node, 200, $today, '');
    $this->dateRangeTest($node, 403, $ten_days_in_the_future, '');

    // End date.
    $this->dateRangeTest($node, 403, '', $ten_days_in_the_past);
    $this->dateRangeTest($node, 403, '', $today);
    $this->dateRangeTest($node, 200, '', $ten_days_in_the_future);

    // Date range.
    $this->dateRangeTest($node, 403, $ten_days_in_the_past, $five_days_in_the_past);
    $this->dateRangeTest($node, 200, $ten_days_in_the_past, $ten_days_in_the_future);
    $this->dateRangeTest($node, 403, $ten_days_in_the_past, $today);
    $this->dateRangeTest($node, 200, $today, $ten_days_in_the_future);
    $this->dateRangeTest($node, 403, $five_days_in_the_future, $ten_days_in_the_future);
  }

  /**
   * Helper function.
   *
   * Check status code depending on date conditions.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The node used for tests.
   * @param int $expected_status_code
   *   The expected status code.
   * @param string $begin_date
   *   The begin date.
   * @param string $end_date
   *   The end date.
   */
  protected function dateRangeTest(NodeInterface $node, int $expected_status_code = 200, string $begin_date = '', string $end_date = '') {
    $node->set('field_entity_visibility_preview', serialize([
      'date_range_condition' => [
        'value' => $begin_date,
        'end_value' => $end_date,
      ],
    ]));
    $node->save();
    $this->drupalGet($node->toUrl());
    $this->assertSession()->statusCodeEquals($expected_status_code);
  }

}

==> entity_visibility_preview-8.x-1.7.tar.gz: entity_visibility_preview/tests/src/Functional/DateRangeConditionTest.php <==
<?php

declare(strict_types = 1);

namespace Drupal\Tests\entity_visibility_preview\Functional;

use Drupal\node\NodeInterface;

/**
 * Tests for the Date range condition plugin.
 *
 * @group entity_visibility_preview
 */
class DateRangeConditionTest extends EntityVisibilityPreviewFunctionalTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'datetime',
  ];

  /**
   * {@inheritdoc}
   */
  protected $fieldSettings = [
    'enabled_condition_plugins' => [
      'date_range_condition' => 'date_range_condition',
    ],
  ];

  /**
   * Test the cases of the date range plugin.
   */
  public function testDateRangePlugin() {
    $node = $this->drupalCreateNode([
      'type' => 'article',
      'status' => NodeInterface::PUBLISHED,
    ]);

    // Test that the user has access to the node.
    $this->dateRangeTest($node, 200, '', '');

    // Begin date.
    $this->dateRangeTest($node, 200, $this->tenDaysInThePast, '');
    $this->dateRangeTest($node, 200, $this->today, '');
    $this->dateRangeTest($node, 403, $this->tenDaysInTheFuture, '');

    // End date.
    $this->dateRangeTest($node, 403, '', $this->tenDaysInThePast);
    $this->dateRangeTest($node, 403, '', $this->today);
    $this->dateRangeTest($node, 200, '', $this->tenDaysInTheFuture);

    // Date range.
    $this->dateRangeTest($node, 403, $this->tenDaysInThePast, $this->fiveDaysInThePast);
    $this->dateRangeTest($node, 200, $this->tenDaysInThePast, $this->tenDaysInTheFuture);
    $this->dateRangeTest($node, 403, $this->tenDaysInThePast, $this->today);
    $this->dateRangeTest($node, 200, $this->today, $this->tenDaysInTheFuture);
    $this->dateRangeTest($node, 403, $this->fiveDaysInTheFuture, $this->tenDaysInTheFuture);
  }

  /**
   * Helper function.
   *
   * Check status code depending on date conditions.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The node used for tests.
   * @param int $expected_status_code
   *   The expected status code.
   * @param string $begin_date
   *   The begin date.
   * @param string $end_date
   *   The end date.
   */
  protected function dateRangeTest(NodeInterface $node, int $expected_status_code = 200, string $begin_date = '', string $end_date = '') {
    $node->set($this->fieldName, serialize([
      'date_range_condition' => [
        'value' => $begin_date,
        'end_value' => $end_date,
      ],
    ]));
    $node->save();
    $this->drupalGet($node->toUrl());
    $this->assertSession()->statusCodeEquals($expected_status_code);
  }

}
